nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Usart

Struct Usart 

pub struct Usart { /* private fields */ }
LPC_Next0 USARTs

Implementations

Source

impl Usart

pub const unsafe fn from_ptr(ptr: *mut ()) -> Self

pub const fn as_ptr(&self) -> *mut ()

pub const fn cfg(self) -> Reg<Cfg, RW>

USART Configuration register. Basic USART configuration settings that typically are not changed during operation.

pub const fn ctl(self) -> Reg<Ctl, RW>

USART Control register. USART control settings that are more likely to change during operation.

pub const fn stat(self) -> Reg<Stat, RW>

USART Status register. The complete status value can be read here. Writing ones clears some bits in the register. Some bits can be cleared by writing a 1 to them.

pub const fn intenset(self) -> Reg<Intenset, RW>

Interrupt Enable read and Set register for USART (not FIFO) status. Contains individual interrupt enable bits for each potential USART interrupt. A complete value may be read from this register. Writing a 1 to any implemented bit position causes that bit to be set.

pub const fn intenclr(self) -> Reg<Intenclr, W>

Interrupt Enable Clear register. Allows clearing any combination of bits in the INTENSET register. Writing a 1 to any implemented bit position causes the corresponding bit to be cleared.

pub const fn brg(self) -> Reg<Brg, RW>

Baud Rate Generator register. 16-bit integer baud rate divisor value.

pub const fn intstat(self) -> Reg<Intstat, R>

Interrupt status register. Reflects interrupts that are currently enabled.

pub const fn osr(self) -> Reg<Osr, RW>

Oversample selection register for asynchronous communication.

pub const fn addr(self) -> Reg<Addr, RW>

Address register for automatic address matching.

pub const fn fifocfg(self) -> Reg<Fifocfg, RW>

FIFO configuration and enable register.

pub const fn fifostat(self) -> Reg<Fifostat, RW>

FIFO status register.

pub const fn fifotrig(self) -> Reg<Fifotrig, RW>

FIFO trigger settings for interrupt and DMA request.

pub const fn fifointenset(self) -> Reg<Fifointenset, RW>

FIFO interrupt enable set (enable) and read register.

pub const fn fifointenclr(self) -> Reg<Fifointenclr, RW>

FIFO interrupt enable clear (disable) and read register.

pub const fn fifointstat(self) -> Reg<Fifointstat, R>

FIFO interrupt status register.

pub const fn fifowr(self) -> Reg<Fifowr, W>

FIFO write data.

pub const fn fiford(self) -> Reg<Fiford, R>

FIFO read data.

pub const fn fifordnopop(self) -> Reg<Fifordnopop, R>

FIFO data read with no FIFO pop.

pub const fn fifosize(self) -> Reg<Fifosize, RW>

FIFO size register

pub const fn id(self) -> Reg<Id, R>

Peripheral identification register.