pub struct Usart { /* private fields */ }Expand description
LPC_Next0 USARTs
Implementations
Sourceimpl Usart
impl Usart
pub const unsafe fn from_ptr(ptr: *mut ()) -> Self
pub const fn as_ptr(&self) -> *mut ()
Sourcepub const fn cfg(self) -> Reg<Cfg, RW>
pub const fn cfg(self) -> Reg<Cfg, RW>
USART Configuration register. Basic USART configuration settings that typically are not changed during operation.
Sourcepub const fn ctl(self) -> Reg<Ctl, RW>
pub const fn ctl(self) -> Reg<Ctl, RW>
USART Control register. USART control settings that are more likely to change during operation.
Sourcepub const fn stat(self) -> Reg<Stat, RW>
pub const fn stat(self) -> Reg<Stat, RW>
USART Status register. The complete status value can be read here. Writing ones clears some bits in the register. Some bits can be cleared by writing a 1 to them.
Sourcepub const fn intenset(self) -> Reg<Intenset, RW>
pub const fn intenset(self) -> Reg<Intenset, RW>
Interrupt Enable read and Set register for USART (not FIFO) status. Contains individual interrupt enable bits for each potential USART interrupt. A complete value may be read from this register. Writing a 1 to any implemented bit position causes that bit to be set.
Sourcepub const fn intenclr(self) -> Reg<Intenclr, W>
pub const fn intenclr(self) -> Reg<Intenclr, W>
Interrupt Enable Clear register. Allows clearing any combination of bits in the INTENSET register. Writing a 1 to any implemented bit position causes the corresponding bit to be cleared.
Sourcepub const fn brg(self) -> Reg<Brg, RW>
pub const fn brg(self) -> Reg<Brg, RW>
Baud Rate Generator register. 16-bit integer baud rate divisor value.
Sourcepub const fn intstat(self) -> Reg<Intstat, R>
pub const fn intstat(self) -> Reg<Intstat, R>
Interrupt status register. Reflects interrupts that are currently enabled.
Sourcepub const fn osr(self) -> Reg<Osr, RW>
pub const fn osr(self) -> Reg<Osr, RW>
Oversample selection register for asynchronous communication.
Sourcepub const fn fifotrig(self) -> Reg<Fifotrig, RW>
pub const fn fifotrig(self) -> Reg<Fifotrig, RW>
FIFO trigger settings for interrupt and DMA request.
Sourcepub const fn fifointenset(self) -> Reg<Fifointenset, RW>
pub const fn fifointenset(self) -> Reg<Fifointenset, RW>
FIFO interrupt enable set (enable) and read register.
Sourcepub const fn fifointenclr(self) -> Reg<Fifointenclr, RW>
pub const fn fifointenclr(self) -> Reg<Fifointenclr, RW>
FIFO interrupt enable clear (disable) and read register.
Sourcepub const fn fifointstat(self) -> Reg<Fifointstat, R>
pub const fn fifointstat(self) -> Reg<Fifointstat, R>
FIFO interrupt status register.
Sourcepub const fn fifordnopop(self) -> Reg<Fifordnopop, R>
pub const fn fifordnopop(self) -> Reg<Fifordnopop, R>
FIFO data read with no FIFO pop.